@@ -2,15 +2,18 @@ package net.thunderbird.app.common.account
 
 import app.k9mail.feature.account.setup.AccountSetupExternalContract
 import net.thunderbird.app.common.account.data.DefaultAccountProfileLocalDataSource
-import net.thunderbird.app.common.account.data.DefaultLegacyAccountWrapperManager
+import net.thunderbird.app.common.account.data.DefaultLegacyAccountManager
 import net.thunderbird.core.android.account.AccountDefaultsProvider
-import net.thunderbird.core.android.account.LegacyAccountWrapperManager
+import net.thunderbird.core.android.account.LegacyAccount
+import net.thunderbird.core.android.account.LegacyAccountManager
 import net.thunderbird.feature.account.avatar.AvatarMonogramCreator
 import net.thunderbird.feature.account.avatar.DefaultAvatarMonogramCreator
 import net.thunderbird.feature.account.core.AccountCoreExternalContract.AccountProfileLocalDataSource
 import net.thunderbird.feature.account.core.featureAccountCoreModule
 import net.thunderbird.feature.account.storage.legacy.featureAccountStorageLegacyModule
+import net.thunderbird.feature.mail.account.api.AccountManager
 import org.koin.android.ext.koin.androidApplication
+import org.koin.dsl.binds
 import org.koin.dsl.module
 
 internal val appCommonAccountModule = module {
@@ -19,12 +22,12 @@ internal val appCommonAccountModule = module {
         featureAccountStorageLegacyModule,
     )
 
-    single<LegacyAccountWrapperManager> {
-        DefaultLegacyAccountWrapperManager(
+    single<AccountManager<LegacyAccount>> {
+        DefaultLegacyAccountManager(
             accountManager = get(),
             accountDataMapper = get(),
         )
-    }
+    } binds arrayOf(LegacyAccountManager::class)
 
     single<AccountProfileLocalDataSource> {
         DefaultAccountProfileLocalDataSource(
