@@ -1,5 +1,6 @@
 package app.k9mail.provider
 
+import app.k9mail.core.android.common.provider.NotificationIconResourceProvider
 import com.fsck.k9.preferences.FilePrefixProvider
 import net.thunderbird.core.common.provider.AppNameProvider
 import net.thunderbird.core.common.provider.BrandNameProvider
@@ -17,4 +18,8 @@ internal val providerModule = module {
     single<ThemeProvider> { K9ThemeProvider() }
 
     single<FeatureThemeProvider> { K9FeatureThemeProvider() }
+
+    single<NotificationIconResourceProvider> {
+        K9AppNotificationIconProvider()
+    }
 }
