@@ -9,6 +9,9 @@ enum class CatalogOrganismPage(
 ) : CatalogPage {
     APP_BAR("App Bars"),
     DIALOG("Dialogs"),
+    BANNER("Banners"),
+    SNACKBAR("Snackbars", isFullScreen = true),
+    MESSAGE_ITEM("Message Items"),
     ;
 
     override fun toString(): String {
