@@ -2,6 +2,7 @@ package net.thunderbird.core.preference
 
 import net.thunderbird.core.preference.debugging.DebuggingSettings
 import net.thunderbird.core.preference.display.DisplaySettings
+import net.thunderbird.core.preference.interaction.InteractionSettings
 import net.thunderbird.core.preference.network.NetworkSettings
 import net.thunderbird.core.preference.notification.NotificationPreference
 import net.thunderbird.core.preference.privacy.PrivacySettings
@@ -20,6 +21,7 @@ data class GeneralSettings(
     val display: DisplaySettings = DisplaySettings(),
     val privacy: PrivacySettings = PrivacySettings(),
     val debugging: DebuggingSettings = DebuggingSettings(),
+    val interaction: InteractionSettings = InteractionSettings(),
 )
 
 enum class BackgroundSync {
