@@ -1,6 +1,7 @@
 package app.k9mail.core.ui.compose.designsystem.template
 
 import androidx.compose.foundation.layout.fillMaxSize
+import androidx.compose.foundation.layout.padding
 import androidx.compose.runtime.Composable
 import androidx.compose.ui.Modifier
 import app.k9mail.core.ui.compose.common.annotation.PreviewDevices
@@ -14,10 +15,12 @@ import app.k9mail.core.ui.compose.theme2.MainTheme
 internal fun ResponsiveWidthContainerPreview() {
     PreviewWithTheme {
         Surface {
-            ResponsiveWidthContainer {
+            ResponsiveWidthContainer { contentPadding ->
                 Surface(
                     color = MainTheme.colors.error,
-                    modifier = Modifier.fillMaxSize(),
+                    modifier = Modifier
+                        .fillMaxSize()
+                        .padding(contentPadding),
                 ) {
                     TextBodyLarge("Hello, World!")
                 }
