@@ -9,11 +9,13 @@ import app.k9mail.feature.account.server.settings.ui.incoming.IncomingServerSett
 import app.k9mail.feature.account.server.settings.ui.outgoing.OutgoingServerSettingsContract
 import app.k9mail.feature.account.server.validation.ui.ServerValidationContract
 import org.junit.Test
+import org.koin.core.annotation.KoinExperimentalAPI
 import org.koin.test.KoinTest
 import org.koin.test.verify.verify
 
 class AccountEditModuleKtTest : KoinTest {
 
+    @OptIn(KoinExperimentalAPI::class)
     @Test
     fun `should have a valid di module`() {
         featureAccountEditModule.verify(
