@@ -5,11 +5,18 @@ plugins {
 android {
     namespace = "app.k9mail.feature.account.server.settings"
     resourcePrefix = "account_server_settings_"
+
+    testOptions {
+        unitTests {
+            isIncludeAndroidResources = true
+        }
+    }
 }
 
 dependencies {
     implementation(projects.core.ui.compose.designsystem)
     implementation(projects.core.common)
+    implementation(projects.core.validation)
 
     implementation(projects.mail.common)
     implementation(projects.mail.protocols.imap)
