@@ -4,7 +4,7 @@ import app.k9mail.feature.account.server.settings.domain.usecase.ValidatePasswor
 import app.k9mail.feature.account.server.settings.domain.usecase.ValidatePort
 import app.k9mail.feature.account.server.settings.domain.usecase.ValidateServer
 import app.k9mail.feature.account.server.settings.domain.usecase.ValidateUsername
-import net.thunderbird.core.common.domain.usecase.validation.ValidationResult
+import net.thunderbird.core.validation.ValidationOutcome
 
 internal class OutgoingServerSettingsValidator(
     private val serverValidator: ValidateServer = ValidateServer(),
@@ -12,19 +12,19 @@ internal class OutgoingServerSettingsValidator(
     private val usernameValidator: ValidateUsername = ValidateUsername(),
     private val passwordValidator: ValidatePassword = ValidatePassword(),
 ) : OutgoingServerSettingsContract.Validator {
-    override fun validateServer(server: String): ValidationResult {
+    override fun validateServer(server: String): ValidationOutcome {
         return serverValidator.execute(server)
     }
 
-    override fun validatePort(port: Long?): ValidationResult {
+    override fun validatePort(port: Long?): ValidationOutcome {
         return portValidator.execute(port)
     }
 
-    override fun validateUsername(username: String): ValidationResult {
+    override fun validateUsername(username: String): ValidationOutcome {
         return usernameValidator.execute(username)
     }
 
-    override fun validatePassword(password: String): ValidationResult {
+    override fun validatePassword(password: String): ValidationOutcome {
         return passwordValidator.execute(password)
     }
 }
