@@ -3,7 +3,7 @@ package net.thunderbird.feature.account.settings.impl.ui.general
 import androidx.compose.runtime.Composable
 import androidx.compose.ui.Modifier
 import androidx.compose.ui.res.stringResource
-import net.thunderbird.core.ui.compose.preference.ui.PreferenceView
+import net.thunderbird.core.ui.setting.SettingViewProvider
 import net.thunderbird.feature.account.settings.R
 import net.thunderbird.feature.account.settings.impl.ui.general.GeneralSettingsContract.Event
 import net.thunderbird.feature.account.settings.impl.ui.general.GeneralSettingsContract.State
@@ -12,14 +12,15 @@ import net.thunderbird.feature.account.settings.impl.ui.general.GeneralSettingsC
 internal fun GeneralSettingsContent(
     state: State,
     onEvent: (Event) -> Unit,
+    provider: SettingViewProvider,
     modifier: Modifier = Modifier,
 ) {
-    PreferenceView(
+    provider.SettingView(
         title = stringResource(R.string.account_settings_general_title),
         subtitle = state.subtitle,
-        preferences = state.preferences,
-        onPreferenceChange = { preference ->
-            onEvent(Event.OnPreferenceSettingChange(preference))
+        settings = state.settings,
+        onSettingValueChange = { setting ->
+            onEvent(Event.OnSettingValueChange(setting))
         },
         onBack = { onEvent(Event.OnBackPressed) },
         modifier = modifier,
