@@ -21,4 +21,9 @@ internal class FakeGeneralResourceProvider : ResourceProvider.GeneralResourcePro
     override val colorDescription: () -> String? = { null }
     override val colorIcon: () -> ImageVector? = { null }
     override val colors: ImmutableList<Int> = persistentListOf(0xFF0000, 0x00FF00, 0x0000FF)
+
+    override val profileIndicatorIcon: () -> String = { "ProfileIndicatorIcon" }
+    override val profileIndicatorImage: () -> String = { "ProfileIndicatorImage" }
+    override val profileIndicatorMonogram: () -> String = { "ProfileIndicatorMonogram" }
+    override val profileIndicatorTitle: () -> String = { "Profile Indicator" }
 }
