@@ -3,7 +3,7 @@ package net.thunderbird.feature.account.settings.impl.ui.general
 import assertk.assertThat
 import assertk.assertions.isEqualTo
 import kotlin.test.Test
-import kotlinx.collections.immutable.persistentListOf
+import net.thunderbird.core.ui.setting.emptySettings
 import net.thunderbird.feature.account.settings.impl.ui.general.GeneralSettingsContract.State
 
 internal class GeneralSettingsStateTest {
@@ -17,7 +17,7 @@ internal class GeneralSettingsStateTest {
         assertThat(state).isEqualTo(
             State(
                 subtitle = null,
-                preferences = persistentListOf(),
+                settings = emptySettings(),
             ),
         )
     }
