@@ -4,7 +4,8 @@ import app.k9mail.feature.account.setup.domain.usecase.ValidateDisplayName.Valid
 import assertk.assertThat
 import assertk.assertions.isInstanceOf
 import assertk.assertions.prop
-import net.thunderbird.core.common.domain.usecase.validation.ValidationResult
+import net.thunderbird.core.outcome.Outcome
+import net.thunderbird.core.validation.ValidationError
 import org.junit.Test
 
 class ValidateDisplayNameTest {
@@ -15,15 +16,15 @@ class ValidateDisplayNameTest {
     fun `should succeed when display name is set`() {
         val result = testSubject.execute("display name")
 
-        assertThat(result).isInstanceOf<ValidationResult.Success>()
+        assertThat(result).isInstanceOf<Outcome.Success<Unit>>()
     }
 
     @Test
     fun `should fail when display name is empty`() {
         val result = testSubject.execute("")
 
-        assertThat(result).isInstanceOf<ValidationResult.Failure>()
-            .prop(ValidationResult.Failure::error)
+        assertThat(result).isInstanceOf<Outcome.Failure<ValidationError>>()
+            .prop(Outcome.Failure<ValidationError>::error)
             .isInstanceOf<ValidateDisplayNameError.EmptyDisplayName>()
     }
 
@@ -31,8 +32,8 @@ class ValidateDisplayNameTest {
     fun `should fail when display name is blank`() {
         val result = testSubject.execute(" ")
 
-        assertThat(result).isInstanceOf<ValidationResult.Failure>()
-            .prop(ValidationResult.Failure::error)
+        assertThat(result).isInstanceOf<Outcome.Failure<ValidationError>>()
+            .prop(Outcome.Failure<ValidationError>::error)
             .isInstanceOf<ValidateDisplayNameError.EmptyDisplayName>()
     }
 }
