@@ -4,9 +4,10 @@ import app.k9mail.feature.account.setup.domain.usecase.ValidateEmailAddress.Vali
 import assertk.assertThat
 import assertk.assertions.isInstanceOf
 import assertk.assertions.prop
-import net.thunderbird.core.common.domain.usecase.validation.ValidationResult
 import net.thunderbird.core.logging.legacy.Log
 import net.thunderbird.core.logging.testing.TestLogger
+import net.thunderbird.core.outcome.Outcome
+import net.thunderbird.core.validation.ValidationError
 import org.junit.Before
 import org.junit.Test
 
@@ -23,15 +24,15 @@ class ValidateEmailAddressTest {
     fun `should succeed when email address is valid`() {
         val result = testSubject.execute("test@example.com")
 
-        assertThat(result).isInstanceOf<ValidationResult.Success>()
+        assertThat(result).isInstanceOf<Outcome.Success<Unit>>()
     }
 
     @Test
     fun `should fail when email address is blank`() {
         val result = testSubject.execute(" ")
 
-        assertThat(result).isInstanceOf<ValidationResult.Failure>()
-            .prop(ValidationResult.Failure::error)
+        assertThat(result).isInstanceOf<Outcome.Failure<ValidationError>>()
+            .prop(Outcome.Failure<ValidationError>::error)
             .isInstanceOf<ValidateEmailAddressError.EmptyEmailAddress>()
     }
 
@@ -39,8 +40,8 @@ class ValidateEmailAddressTest {
     fun `should fail when email address is using unnecessary quoting in local part`() {
         val result = testSubject.execute("\"local-part\"@domain.example")
 
-        assertThat(result).isInstanceOf<ValidationResult.Failure>()
-            .prop(ValidationResult.Failure::error)
+        assertThat(result).isInstanceOf<Outcome.Failure<ValidationError>>()
+            .prop(Outcome.Failure<ValidationError>::error)
             .isInstanceOf<ValidateEmailAddressError.NotAllowed>()
     }
 
@@ -48,8 +49,8 @@ class ValidateEmailAddressTest {
     fun `should fail when email address requires quoted local part`() {
         val result = testSubject.execute("\"local part\"@domain.example")
 
-        assertThat(result).isInstanceOf<ValidationResult.Failure>()
-            .prop(ValidationResult.Failure::error)
+        assertThat(result).isInstanceOf<Outcome.Failure<ValidationError>>()
+            .prop(Outcome.Failure<ValidationError>::error)
             .isInstanceOf<ValidateEmailAddressError.NotAllowed>()
     }
 
@@ -57,8 +58,8 @@ class ValidateEmailAddressTest {
     fun `should fail when local part is empty`() {
         val result = testSubject.execute("\"\"@domain.example")
 
-        assertThat(result).isInstanceOf<ValidationResult.Failure>()
-            .prop(ValidationResult.Failure::error)
+        assertThat(result).isInstanceOf<Outcome.Failure<ValidationError>>()
+            .prop(Outcome.Failure<ValidationError>::error)
             .isInstanceOf<ValidateEmailAddressError.NotAllowed>()
     }
 
@@ -66,8 +67,8 @@ class ValidateEmailAddressTest {
     fun `should fail when domain part contains IPv4 literal`() {
         val result = testSubject.execute("user@[255.0.100.23]")
 
-        assertThat(result).isInstanceOf<ValidationResult.Failure>()
-            .prop(ValidationResult.Failure::error)
+        assertThat(result).isInstanceOf<Outcome.Failure<ValidationError>>()
+            .prop(Outcome.Failure<ValidationError>::error)
             .isInstanceOf<ValidateEmailAddressError.NotAllowed>()
     }
 
@@ -75,8 +76,8 @@ class ValidateEmailAddressTest {
     fun `should fail when domain part contains IPv6 literal`() {
         val result = testSubject.execute("user@[IPv6:2001:0db8:0000:0000:0000:ff00:0042:8329]")
 
-        assertThat(result).isInstanceOf<ValidationResult.Failure>()
-            .prop(ValidationResult.Failure::error)
+        assertThat(result).isInstanceOf<Outcome.Failure<ValidationError>>()
+            .prop(Outcome.Failure<ValidationError>::error)
             .isInstanceOf<ValidateEmailAddressError.NotAllowed>()
     }
 
@@ -84,8 +85,8 @@ class ValidateEmailAddressTest {
     fun `should fail when local part contains non-ASCII character`() {
         val result = testSubject.execute("töst@domain.example")
 
-        assertThat(result).isInstanceOf<ValidationResult.Failure>()
-            .prop(ValidationResult.Failure::error)
+        assertThat(result).isInstanceOf<Outcome.Failure<ValidationError>>()
+            .prop(Outcome.Failure<ValidationError>::error)
             .isInstanceOf<ValidateEmailAddressError.InvalidOrNotSupported>()
     }
 
@@ -93,8 +94,8 @@ class ValidateEmailAddressTest {
     fun `should fail when domain contains non-ASCII character`() {
         val result = testSubject.execute("test@dömain.example")
 
-        assertThat(result).isInstanceOf<ValidationResult.Failure>()
-            .prop(ValidationResult.Failure::error)
+        assertThat(result).isInstanceOf<Outcome.Failure<ValidationError>>()
+            .prop(Outcome.Failure<ValidationError>::error)
             .isInstanceOf<ValidateEmailAddressError.InvalidOrNotSupported>()
     }
 
@@ -102,8 +103,8 @@ class ValidateEmailAddressTest {
     fun `should fail when email address is invalid`() {
         val result = testSubject.execute("test")
 
-        assertThat(result).isInstanceOf<ValidationResult.Failure>()
-            .prop(ValidationResult.Failure::error)
+        assertThat(result).isInstanceOf<Outcome.Failure<ValidationError>>()
+            .prop(Outcome.Failure<ValidationError>::error)
             .isInstanceOf<ValidateEmailAddressError.InvalidEmailAddress>()
     }
 }
