@@ -4,29 +4,35 @@ import androidx.compose.foundation.layout.fillMaxSize
 import androidx.compose.runtime.Composable
 import androidx.compose.ui.Modifier
 import androidx.compose.ui.tooling.preview.PreviewLightDark
+import app.k9mail.core.android.common.provider.NotificationIconResourceProvider
 import app.k9mail.core.ui.compose.common.koin.koinPreview
 import app.k9mail.core.ui.compose.designsystem.PreviewWithThemesLightDark
 import kotlinx.coroutines.flow.Flow
-import kotlinx.coroutines.flow.SharedFlow
+import kotlinx.coroutines.flow.MutableStateFlow
+import kotlinx.coroutines.flow.StateFlow
 import kotlinx.coroutines.flow.flowOf
 import net.thunderbird.core.common.resources.StringsResourceManager
 import net.thunderbird.feature.debug.settings.notification.DebugNotificationSectionViewModel
 import net.thunderbird.feature.mail.account.api.AccountManager
 import net.thunderbird.feature.mail.account.api.BaseAccount
 import net.thunderbird.feature.notification.api.command.outcome.NotificationCommandOutcome
+import net.thunderbird.feature.notification.api.content.InAppNotification
 import net.thunderbird.feature.notification.api.content.Notification
-import net.thunderbird.feature.notification.api.receiver.InAppNotificationEvent
-import net.thunderbird.feature.notification.api.receiver.InAppNotificationReceiver
+import net.thunderbird.feature.notification.api.receiver.InAppNotificationStream
 import net.thunderbird.feature.notification.api.sender.NotificationSender
 
 @PreviewLightDark
 @Composable
 private fun SecretDebugSettingsScreenPreview() {
     koinPreview {
-        single<InAppNotificationReceiver> {
-            object : InAppNotificationReceiver {
-                override val events: SharedFlow<InAppNotificationEvent>
-                    get() = error("not implemented")
+        single<InAppNotificationStream> {
+            object : InAppNotificationStream {
+                override val notifications: StateFlow<Set<InAppNotification>> = MutableStateFlow(emptySet())
+            }
+        }
+        single<NotificationIconResourceProvider> {
+            object : NotificationIconResourceProvider {
+                override val pushNotificationIcon: Int = 0
             }
         }
         single<DebugNotificationSectionViewModel> {
@@ -54,7 +60,8 @@ private fun SecretDebugSettingsScreenPreview() {
                     ): Flow<NotificationCommandOutcome<Notification>> =
                         error("not implemented")
                 },
-                notificationReceiver = get(),
+                inAppNotificationStream = get(),
+                notificationIconResourceProvider = get(),
             )
         }
     } WithContent {
