@@ -9,7 +9,10 @@ android {
 kotlin {
     sourceSets {
         commonMain.dependencies {
+            implementation(projects.core.outcome)
+            implementation(projects.feature.account.api)
             implementation(projects.feature.mail.account.api)
+            implementation(libs.androidx.annotation)
         }
     }
 }
