@@ -7,9 +7,10 @@ import app.k9mail.core.ui.compose.testing.ComposeTest
 
 internal fun ComposeTest.printSemanticTree(
     root: SemanticsNodeInteraction = composeTestRule.onRoot(useUnmergedTree = true),
+    prefixLabel: String = "",
 ) {
     println("-----")
-    println("Semantic tree:")
+    println("$prefixLabel Semantic tree:")
     println(root.printToString())
     println("-----")
     println()
