@@ -13,12 +13,14 @@ kotlin {
             implementation(projects.feature.notification.api)
         }
         commonTest.dependencies {
+            implementation(projects.core.testing)
             implementation(projects.core.logging.testing)
             implementation(projects.feature.notification.testing)
         }
         androidMain.dependencies {
             // should split feature.launcher into api/impl?
             implementation(projects.feature.launcher)
+            implementation(projects.core.ui.theme.api)
         }
         androidUnitTest.dependencies {
             implementation(libs.androidx.test.core)
