@@ -4,7 +4,6 @@ import net.thunderbird.core.logging.Logger
 import net.thunderbird.feature.notification.api.NotificationId
 import net.thunderbird.feature.notification.api.NotificationRegistry
 import net.thunderbird.feature.notification.api.content.InAppNotification
-import net.thunderbird.feature.notification.api.receiver.InAppNotificationEvent
 import net.thunderbird.feature.notification.api.receiver.NotificationNotifier
 
 private const val TAG = "InAppNotificationNotifier"
@@ -16,16 +15,11 @@ private const val TAG = "InAppNotificationNotifier"
 internal class InAppNotificationNotifier(
     private val logger: Logger,
     private val notificationRegistry: NotificationRegistry,
-    private val inAppNotificationEventBus: InAppNotificationEventBus,
 ) : NotificationNotifier<InAppNotification> {
 
-    override suspend fun show(id: NotificationId, notification: InAppNotification) {
-        logger.verbose(TAG) { "show() called with: id = $id, notification = $notification" }
-        if (id in notificationRegistry) {
-            inAppNotificationEventBus.publish(
-                event = InAppNotificationEvent.Show(notification),
-            )
-        }
+    override suspend fun show(notification: InAppNotification): NotificationId {
+        logger.verbose(TAG) { "show() called with: notification = $notification" }
+        return notificationRegistry[notification] ?: notificationRegistry.register(notification)
     }
 
     override suspend fun dismiss(id: NotificationId) {
@@ -33,9 +27,6 @@ internal class InAppNotificationNotifier(
         val notification = notificationRegistry[id]
         if (notification != null && notification is InAppNotification) {
             notificationRegistry.unregister(notification)
-            inAppNotificationEventBus.publish(
-                event = InAppNotificationEvent.Dismiss(notification),
-            )
         }
     }
 
