@@ -2,4 +2,4 @@ package net.thunderbird.feature.notification.testing.fake.icon
 
 import net.thunderbird.feature.notification.api.ui.icon.SystemNotificationIcon
 
-internal actual val EMPTY_SYSTEM_NOTIFICATION_ICON: SystemNotificationIcon = 0
+actual val EMPTY_SYSTEM_NOTIFICATION_ICON: SystemNotificationIcon = 0
