@@ -4,9 +4,9 @@ import com.fsck.k9.mail.ServerSettings
 import com.fsck.k9.mail.store.imap.ImapStoreSettings
 import com.fsck.k9.mail.store.imap.ImapStoreSettings.autoDetectNamespace
 import com.fsck.k9.mail.store.imap.ImapStoreSettings.pathPrefix
-import net.thunderbird.core.android.account.LegacyAccount
+import net.thunderbird.core.android.account.LegacyAccountDto
 
-fun LegacyAccount.toImapServerSettings(): ServerSettings {
+fun LegacyAccountDto.toImapServerSettings(): ServerSettings {
     val serverSettings = incomingServerSettings
     return serverSettings.copy(
         extra = ImapStoreSettings.createExtra(
