@@ -7,13 +7,13 @@ import java.util.Map;
 import java.util.Map.Entry;
 import app.k9mail.legacy.message.controller.MessagingListener;
 import app.k9mail.legacy.message.controller.SimpleMessagingListener;
-import net.thunderbird.core.android.account.LegacyAccount;
+import net.thunderbird.core.android.account.LegacyAccountDto;
 
 
 class MemorizingMessagingListener extends SimpleMessagingListener {
     Map<String, Memory> memories = new HashMap<>(31);
 
-    synchronized void removeAccount(LegacyAccount account) {
+    synchronized void removeAccount(LegacyAccountDto account) {
         Iterator<Entry<String, Memory>> memIt = memories.entrySet().iterator();
 
         while (memIt.hasNext()) {
@@ -63,7 +63,7 @@ class MemorizingMessagingListener extends SimpleMessagingListener {
     }
 
     @Override
-    public synchronized void synchronizeMailboxStarted(LegacyAccount account, long folderId) {
+    public synchronized void synchronizeMailboxStarted(LegacyAccountDto account, long folderId) {
         Memory memory = getMemory(account, folderId);
         memory.syncingState = MemorizingState.STARTED;
         memory.folderCompleted = 0;
@@ -71,13 +71,13 @@ class MemorizingMessagingListener extends SimpleMessagingListener {
     }
 
     @Override
-    public synchronized void synchronizeMailboxFinished(LegacyAccount account, long folderId) {
+    public synchronized void synchronizeMailboxFinished(LegacyAccountDto account, long folderId) {
         Memory memory = getMemory(account, folderId);
         memory.syncingState = MemorizingState.FINISHED;
     }
 
     @Override
-    public synchronized void synchronizeMailboxFailed(LegacyAccount account, long folderId,
+    public synchronized void synchronizeMailboxFailed(LegacyAccountDto account, long folderId,
             String message) {
 
         Memory memory = getMemory(account, folderId);
@@ -86,14 +86,14 @@ class MemorizingMessagingListener extends SimpleMessagingListener {
     }
 
     @Override
-    public synchronized void synchronizeMailboxProgress(LegacyAccount account, long folderId, int completed,
+    public synchronized void synchronizeMailboxProgress(LegacyAccountDto account, long folderId, int completed,
             int total) {
         Memory memory = getMemory(account, folderId);
         memory.folderCompleted = completed;
         memory.folderTotal = total;
     }
 
-    private Memory getMemory(LegacyAccount account, long folderId) {
+    private Memory getMemory(LegacyAccountDto account, long folderId) {
         Memory memory = memories.get(getMemoryKey(account, folderId));
         if (memory == null) {
             memory = new Memory(account, folderId);
@@ -102,14 +102,14 @@ class MemorizingMessagingListener extends SimpleMessagingListener {
         return memory;
     }
 
-    private static String getMemoryKey(LegacyAccount account, long folderId) {
+    private static String getMemoryKey(LegacyAccountDto account, long folderId) {
         return account.getUuid() + ":" + folderId;
     }
 
     private enum MemorizingState { STARTED, FINISHED, FAILED }
 
     private static class Memory {
-        LegacyAccount account;
+        LegacyAccountDto account;
         long folderId;
         MemorizingState syncingState = null;
         String failureMessage = null;
@@ -117,7 +117,7 @@ class MemorizingMessagingListener extends SimpleMessagingListener {
         int folderCompleted = 0;
         int folderTotal = 0;
 
-        Memory(LegacyAccount account, long folderId) {
+        Memory(LegacyAccountDto account, long folderId) {
             this.account = account;
             this.folderId = folderId;
         }
