@@ -3,7 +3,7 @@ package com.fsck.k9.notification
 import app.k9mail.legacy.message.controller.MessageReference
 import com.fsck.k9.mailstore.LocalFolder
 import com.fsck.k9.mailstore.LocalMessage
-import net.thunderbird.core.android.account.LegacyAccount
+import net.thunderbird.core.android.account.LegacyAccountDto
 import net.thunderbird.core.logging.legacy.Log
 
 class NotificationController internal constructor(
@@ -13,55 +13,55 @@ class NotificationController internal constructor(
     private val sendFailedNotificationController: SendFailedNotificationController,
     private val newMailNotificationController: NewMailNotificationController,
 ) {
-    fun showCertificateErrorNotification(account: LegacyAccount, incoming: Boolean) {
+    fun showCertificateErrorNotification(account: LegacyAccountDto, incoming: Boolean) {
         certificateErrorNotificationController.showCertificateErrorNotification(account, incoming)
     }
 
-    fun clearCertificateErrorNotifications(account: LegacyAccount, incoming: Boolean) {
+    fun clearCertificateErrorNotifications(account: LegacyAccountDto, incoming: Boolean) {
         certificateErrorNotificationController.clearCertificateErrorNotifications(account, incoming)
     }
 
-    fun showAuthenticationErrorNotification(account: LegacyAccount, incoming: Boolean) {
+    fun showAuthenticationErrorNotification(account: LegacyAccountDto, incoming: Boolean) {
         authenticationErrorNotificationController.showAuthenticationErrorNotification(account, incoming)
     }
 
-    fun clearAuthenticationErrorNotification(account: LegacyAccount, incoming: Boolean) {
+    fun clearAuthenticationErrorNotification(account: LegacyAccountDto, incoming: Boolean) {
         authenticationErrorNotificationController.clearAuthenticationErrorNotification(account, incoming)
     }
 
-    fun showSendingNotification(account: LegacyAccount) {
+    fun showSendingNotification(account: LegacyAccountDto) {
         syncNotificationController.showSendingNotification(account)
     }
 
-    fun clearSendingNotification(account: LegacyAccount) {
+    fun clearSendingNotification(account: LegacyAccountDto) {
         syncNotificationController.clearSendingNotification(account)
     }
 
-    fun showSendFailedNotification(account: LegacyAccount, exception: Exception) {
+    fun showSendFailedNotification(account: LegacyAccountDto, exception: Exception) {
         sendFailedNotificationController.showSendFailedNotification(account, exception)
     }
 
-    fun clearSendFailedNotification(account: LegacyAccount) {
+    fun clearSendFailedNotification(account: LegacyAccountDto) {
         sendFailedNotificationController.clearSendFailedNotification(account)
     }
 
-    fun showFetchingMailNotification(account: LegacyAccount, folder: LocalFolder) {
+    fun showFetchingMailNotification(account: LegacyAccountDto, folder: LocalFolder) {
         syncNotificationController.showFetchingMailNotification(account, folder)
     }
 
-    fun showEmptyFetchingMailNotification(account: LegacyAccount) {
+    fun showEmptyFetchingMailNotification(account: LegacyAccountDto) {
         syncNotificationController.showEmptyFetchingMailNotification(account)
     }
 
-    fun clearFetchingMailNotification(account: LegacyAccount) {
+    fun clearFetchingMailNotification(account: LegacyAccountDto) {
         syncNotificationController.clearFetchingMailNotification(account)
     }
 
-    fun restoreNewMailNotifications(accounts: List<LegacyAccount>) {
+    fun restoreNewMailNotifications(accounts: List<LegacyAccountDto>) {
         newMailNotificationController.restoreNewMailNotifications(accounts)
     }
 
-    fun addNewMailNotification(account: LegacyAccount, message: LocalMessage, silent: Boolean) {
+    fun addNewMailNotification(account: LegacyAccountDto, message: LocalMessage, silent: Boolean) {
         Log.v(
             "Creating notification for message %s:%s:%s",
             message.account.uuid,
@@ -72,7 +72,7 @@ class NotificationController internal constructor(
         newMailNotificationController.addNewMailNotification(account, message, silent)
     }
 
-    fun removeNewMailNotification(account: LegacyAccount, messageReference: MessageReference) {
+    fun removeNewMailNotification(account: LegacyAccountDto, messageReference: MessageReference) {
         Log.v("Removing notification for message %s", messageReference)
 
         newMailNotificationController.removeNewMailNotifications(account, clearNewMessageState = true) {
@@ -81,7 +81,7 @@ class NotificationController internal constructor(
     }
 
     fun clearNewMailNotifications(
-        account: LegacyAccount,
+        account: LegacyAccountDto,
         selector: (List<MessageReference>) -> List<MessageReference>,
     ) {
         Log.v("Removing some notifications for account %s", account.uuid)
@@ -89,7 +89,7 @@ class NotificationController internal constructor(
         newMailNotificationController.removeNewMailNotifications(account, clearNewMessageState = false, selector)
     }
 
-    fun clearNewMailNotifications(account: LegacyAccount, clearNewMessageState: Boolean) {
+    fun clearNewMailNotifications(account: LegacyAccountDto, clearNewMessageState: Boolean) {
         Log.v("Removing all notifications for account %s", account.uuid)
 
         newMailNotificationController.clearNewMailNotifications(account, clearNewMessageState)
