@@ -1,11 +1,11 @@
 package app.k9mail.legacy.mailstore
 
-import net.thunderbird.core.android.account.LegacyAccount
+import net.thunderbird.core.android.account.LegacyAccountDto
 import net.thunderbird.feature.mail.folder.api.FolderType
 
 object FolderTypeMapper {
 
-    fun folderTypeOf(account: LegacyAccount, folderId: Long) = when (folderId) {
+    fun folderTypeOf(account: LegacyAccountDto, folderId: Long) = when (folderId) {
         account.inboxFolderId -> FolderType.INBOX
         account.sentFolderId -> FolderType.SENT
         account.trashFolderId -> FolderType.TRASH
