@@ -2,7 +2,7 @@ package com.fsck.k9.storage.messages
 
 import com.fsck.k9.mailstore.LockableDatabase
 import com.fsck.k9.mailstore.StorageFilesProvider
-import timber.log.Timber
+import net.thunderbird.core.logging.legacy.Log
 
 internal class DatabaseOperations(
     private val lockableDatabase: LockableDatabase,
@@ -27,12 +27,12 @@ internal class DatabaseOperations(
     }
 
     fun compact() {
-        Timber.i("Before compaction size = %d", getSize())
+        Log.i("Before compaction size = %d", getSize())
 
         lockableDatabase.execute(false) { database ->
             database.execSQL("VACUUM")
         }
 
-        Timber.i("After compaction size = %d", getSize())
+        Log.i("After compaction size = %d", getSize())
     }
 }
