@@ -27,11 +27,15 @@ dependencies {
     implementation(projects.feature.notification.api)
     // TODO: Remove AccountOauth dependency
     implementation(projects.feature.account.oauth)
+    implementation(projects.feature.account.avatar.api)
+    implementation(projects.feature.account.avatar.impl)
     implementation(projects.feature.funding.api)
     implementation(projects.feature.search.implLegacy)
     implementation(projects.feature.settings.import)
     implementation(projects.feature.telemetry.api)
     implementation(projects.feature.mail.message.list)
+    implementation(projects.feature.mail.message.composer)
+    implementation(projects.feature.mail.message.export.api)
 
     compileOnly(projects.mail.protocols.imap)
 
@@ -67,6 +71,8 @@ dependencies {
     implementation(libs.mime4j.core)
     implementation(libs.kotlinx.coroutines.core)
     implementation(libs.kotlinx.coroutines.android)
+    implementation(libs.kotlinx.datetime)
+    implementation(libs.uri)
 
     implementation(libs.glide)
     annotationProcessor(libs.glide.compiler)
@@ -94,4 +100,10 @@ android {
     buildFeatures {
         buildConfig = true
     }
+
+    testOptions {
+        unitTests {
+            isIncludeAndroidResources = true
+        }
+    }
 }
