@@ -1,5 +1,6 @@
 package com.fsck.k9.ui.messagelist
 
+import com.fsck.k9.ui.messagelist.debug.AuthDebugActions
 import net.thunderbird.feature.navigation.drawer.dropdown.navigationDropDownDrawerModule
 import net.thunderbird.feature.navigation.drawer.siderail.navigationSideRailDrawerModule
 import org.koin.core.module.dsl.viewModel
@@ -27,5 +28,11 @@ val messageListUiModule = module {
             messageListRepository = get(),
         )
     }
+    factory {
+        AuthDebugActions(
+            accountManager = get(),
+            oAuth2TokenProviderFactory = get(),
+        )
+    }
     single { SortTypeToastProvider() }
 }
