@@ -11,11 +11,11 @@ import androidx.appcompat.widget.AppCompatSpinner
 import androidx.core.view.isVisible
 import com.fsck.k9.ui.R
 import com.google.android.material.textview.MaterialTextView
-import net.thunderbird.core.android.account.LegacyAccount
+import net.thunderbird.core.android.account.LegacyAccountDto
 
 class AccountSelectionSpinner : AppCompatSpinner {
-    var selection: LegacyAccount
-        get() = selectedItem as LegacyAccount
+    var selection: LegacyAccountDto
+        get() = selectedItem as LegacyAccountDto
         set(account) {
             selectedAccount = account
             val adapter = adapter as AccountsAdapter
@@ -24,7 +24,7 @@ class AccountSelectionSpinner : AppCompatSpinner {
         }
 
     private val cachedBackground: Drawable
-    private var selectedAccount: LegacyAccount? = null
+    private var selectedAccount: LegacyAccountDto? = null
 
     constructor(context: Context) : super(context)
     constructor(context: Context, attrs: AttributeSet) : super(context, attrs)
@@ -40,7 +40,7 @@ class AccountSelectionSpinner : AppCompatSpinner {
         adapter.notifyDataSetChanged()
     }
 
-    fun setAccounts(accounts: List<LegacyAccount>) {
+    fun setAccounts(accounts: List<LegacyAccountDto>) {
         val adapter = adapter as AccountsAdapter
         adapter.clear()
         adapter.addAll(accounts)
@@ -52,7 +52,7 @@ class AccountSelectionSpinner : AppCompatSpinner {
         background = if (showAccountSwitcher) cachedBackground else null
     }
 
-    internal class AccountsAdapter(context: Context) : ArrayAdapter<LegacyAccount>(context, 0) {
+    internal class AccountsAdapter(context: Context) : ArrayAdapter<LegacyAccountDto>(context, 0) {
         var title: CharSequence = ""
 
         override fun getView(position: Int, convertView: View?, parent: ViewGroup): View {
