@@ -9,15 +9,14 @@ import static org.junit.Assert.assertArrayEquals;
 
 
 public class AutocryptOperationsHelper {
-    private static AutocryptHeaderParser INSTANCE = AutocryptHeaderParser.getInstance();
 
     public static void assertMessageHasAutocryptHeader(
             MimeMessage message, String addr, boolean isPreferEncryptMutual, byte[] keyData) {
-        AutocryptHeader autocryptHeader = INSTANCE.getValidAutocryptHeader(message);
+        AutocryptHeader autocryptHeader = AutocryptHeaderParser.INSTANCE.getValidAutocryptHeader(message);
 
         assertNotNull(autocryptHeader);
-        assertEquals(addr, autocryptHeader.addr);
-        assertEquals(isPreferEncryptMutual, autocryptHeader.isPreferEncryptMutual);
-        assertArrayEquals(keyData, autocryptHeader.keyData);
+        assertEquals(addr, autocryptHeader.getAddr());
+        assertEquals(isPreferEncryptMutual, autocryptHeader.isPreferEncryptMutual());
+        assertArrayEquals(keyData, autocryptHeader.getKeyData());
     }
 }
