@@ -438,6 +438,8 @@ class MessageListAdapterTest : RobolectricTest() {
             relativeDateTimeFormatter = RelativeDateTimeFormatter(context, TestClock()),
             themeProvider = FakeThemeProvider(),
             featureFlagProvider = FakeFeatureFlagProvider(),
+            avatarMonogramCreator = mock(),
+            contactRepository = mock(),
         )
     }
 
