@@ -19,11 +19,19 @@ import com.fsck.k9.mail.filter.FixedLengthInputStream
 import com.fsck.k9.mail.filter.PeekableInputStream
 import java.io.ByteArrayInputStream
 import java.io.IOException
+import net.thunderbird.core.logging.legacy.Log
+import net.thunderbird.core.logging.testing.TestLogger
+import org.junit.Before
 import org.junit.Test
 
 class ImapResponseParserTest {
     private var peekableInputStream: PeekableInputStream? = null
 
+    @Before
+    fun setup() {
+        Log.logger = TestLogger()
+    }
+
     @Test
     fun `readResponse() with untagged OK response`() {
         val parser = createParserWithResponses("* OK")
@@ -434,6 +442,47 @@ class ImapResponseParserTest {
         assertThatAllInputWasConsumed()
     }
 
+    @Test
+    fun `readResponse() with LIST response containing folder name with UTF8`() {
+        val parser = createParserWithResponses(
+            """* LIST (\HasNoChildren) "." "萬里長城"""",
+            """* LIST (\HasNoChildren) "." "A&-B"""",
+        )
+        parser.setUtf8Accepted(true)
+
+        val response = parser.readResponse()
+        assertThat(response).hasSize(4)
+        assertThat(response).index(3).isEqualTo("萬里長城")
+
+        val response2 = parser.readResponse()
+        assertThat(response2).hasSize(4)
+        assertThat(response2).index(3).isEqualTo("A&-B")
+        assertThatAllInputWasConsumed()
+    }
+
+    @Test
+    fun `readResponse() with LIST response containing ambiguous folder name`() {
+        val parser = createParserWithResponses("""* LIST (\HasNoChildren) "." "A&-B"""")
+
+        val response = parser.readResponse()
+
+        assertThat(response).hasSize(4)
+        assertThat(response).index(3).isEqualTo("A&B")
+        assertThatAllInputWasConsumed()
+    }
+
+    @Test
+    fun `readResponse() with LIST response containing folder name with literal UTF8`() {
+        val parser = createParserWithResponses("""* LIST (\hasnochildren) "/" {18}""" + "\r\nИсходящие")
+
+        parser.setUtf8Accepted(true)
+        val response = parser.readResponse()
+
+        assertThat(response).hasSize(4)
+        assertThat(response).index(3).isEqualTo("Исходящие")
+        assertThatAllInputWasConsumed()
+    }
+
     @Test
     fun `readResponse() with LIST response containing folder name with parentheses should throw`() {
         val parser = createParserWithResponses("""* LIST (\NoInferiors) "/" Root/Folder/Subfolder()""")
@@ -558,7 +607,7 @@ class ImapResponseParserTest {
         val byteArrayInputStream = ByteArrayInputStream(response.toByteArray(Charsets.UTF_8))
         peekableInputStream = PeekableInputStream(byteArrayInputStream)
 
-        return ImapResponseParser(peekableInputStream)
+        return ImapResponseParser(peekableInputStream, FolderNameCodec())
     }
 
     private fun assertThatAllInputWasConsumed() {
